<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "Nem todos os calendários estão completamente pré-carregados",
"Everything seems to be completely cached" => "Parece que tudo está completamente pré-carregado",
"No calendars found." => "Nenhum calendário encontrado.",
"No events found." => "Nenhum evento encontrado.",
"Wrong calendar" => "Calendário errado",
"You do not have the permissions to edit this event." => "Não tem permissões para alterar este evento.",
"The file contained either no events or all events are already saved in your calendar." => "O ficheiro não continha nenhuns eventos ou então todos os eventos já estavam carregados no seu calendário",
"events has been saved in the new calendar" => "Os eventos foram guardados no novo calendário",
"Import failed" => "Falha na importação",
"events has been saved in your calendar" => "Os eventos foram guardados no seu calendário",
"New Timezone:" => "Nova zona horária",
"Timezone changed" => "Zona horária alterada",
"Invalid request" => "Pedido inválido",
"Calendar" => "Calendário",
"Deletion failed" => "Erro ao apagar",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
"user" => "utilizador",
"group" => "grupo",
"Editable" => "Editável",
"Shareable" => "Partilhável",
"Deletable" => "Apagável",
"ddd" => "ddd",
"ddd M/d" => "ddd M/d",
"dddd M/d" => "dddd M/d",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}",
"dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
"Sunday" => "Domingo",
"Monday" => "Segunda",
"Tuesday" => "Terça",
"Wednesday" => "Quarta",
"Thursday" => "Quinta",
"Friday" => "Sexta",
"Saturday" => "Sábado",
"Sun." => "Dom.",
"Mon." => "Seg.",
"Tue." => "ter.",
"Wed." => "Qua.",
"Thu." => "Qui.",
"Fri." => "Sex.",
"Sat." => "Sáb.",
"January" => "Janeiro",
"February" => "Fevereiro",
"March" => "Março",
"April" => "Abril",
"May" => "Maio",
"June" => "Junho",
"July" => "Julho",
"August" => "Agosto",
"September" => "Setembro",
"October" => "Outubro",
"November" => "Novembro",
"December" => "Dezembro",
"Jan." => "Jan.",
"Feb." => "Fev,",
"Mar." => "Mar.",
"Apr." => "Abr.",
"May." => "Mai.",
"Jun." => "Jun.",
"Jul." => "Jul.",
"Aug." => "Ago.",
"Sep." => "Set.",
"Oct." => "Out.",
"Nov." => "Nov.",
"Dec." => "Dez.",
"All day" => "Todo o dia",
"New Calendar" => "Novo Calendário",
"Missing or invalid fields" => "Campos em falta, ou inválidos!",
"Title" => "Título",
"From Date" => "Da Data",
"From Time" => "Da Hora",
"To Date" => "Para Data",
"To Time" => "Para Hora",
"The event ends before it starts" => "O evento acaba antes de começar",
"There was a database fail" => "Houve uma falha de base de dados",
"Birthday" => "Aniversário",
"Business" => "Negócio",
"Call" => "Telefonar",
"Clients" => "Clientes",
"Deliverer" => "Entregar",
"Holidays" => "Férias",
"Ideas" => "Ideias",
"Journey" => "Jornada",
"Jubilee" => "Jublieu",
"Meeting" => "Reunião",
"Other" => "Outro",
"Personal" => "Pessoal",
"Projects" => "Projectos",
"Questions" => "Perguntas",
"Work" => "Trabalho",
"by" => "por",
"unnamed" => "não definido",
"You do not have the permissions to update this calendar." => "Não tem permissões para alterar este calendário.",
"You do not have the permissions to delete this calendar." => "Não tem permissões para apagar este calendário.",
"You do not have the permissions to add to this calendar." => "Não tem permissões para acrescentar a este calendário.",
"You do not have the permissions to add events to this calendar." => "Não tem permissões para acrescentar eventos a este calendário.",
"You do not have the permissions to delete this event." => "Não tem permissões para apagar este evento.",
"Busy" => "Ocupado",
"Public" => "Público",
"Private" => "Privado",
"Confidential" => "Confidencial",
"Does not repeat" => "Não repete",
"Daily" => "Diário",
"Weekly" => "Semanal",
"Every Weekday" => "Todos os dias da semana",
"Bi-Weekly" => "Bi-semanal",
"Monthly" => "Mensal",
"Yearly" => "Anual",
"never" => "nunca",
"by occurrences" => "por ocorrências",
"by date" => "por data",
"by monthday" => "por dia do mês",
"by weekday" => "por dia da semana",
"events week of month" => "Eventos da semana do mês",
"first" => "primeiro",
"second" => "segundo",
"third" => "terçeiro",
"fourth" => "quarto",
"fifth" => "quinto",
"last" => "último",
"by events date" => "por data de evento",
"by yearday(s)" => "por dia(s) do ano",
"by weeknumber(s)" => "por número(s) da semana",
"by day and month" => "por dia e mês",
"Date" => "Data",
"Cal." => "Cal.",
"Week" => "Semana",
"Month" => "Mês",
"List" => "Lista",
"Today" => "Hoje",
"Settings" => "Configurações",
"Your calendars" => "Os seus calendários",
"CalDav Link" => "Endereço CalDav",
"Share Calendar" => "Partilhar calendário",
"Download" => "Transferir",
"Edit" => "Editar",
"Delete" => "Apagar",
"New calendar" => "Novo calendário",
"Edit calendar" => "Editar calendário",
"Displayname" => "Nome de exibição",
"Active" => "Activo",
"Calendar color" => "Cor do calendário",
"Save" => "Guardar",
"Submit" => "Submeter",
"Cancel" => "Cancelar",
"Edit an event" => "Editar um evento",
"Export" => "Exportar",
"Eventinfo" => "Informação do evento",
"Repeating" => "Repetição",
"Alarm" => "Alarme",
"Attendees" => "Participantes",
"Share" => "Partilhar",
"Title of the Event" => "Título do evento",
"Category" => "Categoria",
"Separate categories with commas" => "Separe categorias por virgulas",
"Edit categories" => "Editar categorias",
"Access Class" => "Classe de Acesso",
"All Day Event" => "Evento de dia inteiro",
"From" => "De",
"To" => "Para",
"Advanced options" => "Opções avançadas",
"Location" => "Localização",
"Location of the Event" => "Localização do evento",
"Description" => "Descrição",
"Description of the Event" => "Descrição do evento",
"Repeat" => "Repetir",
"Advanced" => "Avançado",
"Select weekdays" => "Seleciona os dias da semana",
"Select days" => "Seleciona os dias",
"and the events day of year." => "e o dia de eventos do ano.",
"and the events day of month." => "e o dia de eventos do mês.",
"Select months" => "Selecciona os meses",
"Select weeks" => "Selecciona as semanas",
"and the events week of year." => "e a semana de eventos do ano.",
"Interval" => "Intervalo",
"End" => "Fim",
"occurrences" => "ocorrências",
"create a new calendar" => "criar novo calendário",
"Import a calendar file" => "Importar um ficheiro de calendário",
"Please choose a calendar" => "Escolha um calendário por favor",
"Name of new calendar" => "Nome do novo calendário",
"Take an available name!" => "Escolha um nome disponível!",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Já existe um Calendário com esse nome. Se mesmo assim continuar, estes calendários serão fundidos.",
"Remove all events from the selected calendar" => "Remover todos os eventos do calendário seleccionado",
"Import" => "Importar",
"Close Dialog" => "Fechar diálogo",
"Create a new event" => "Criar novo evento",
"Share with:" => "Partilhar com:",
"Shared with" => "Partilhado com:",
"Unshare" => "Deixar de partilhar",
"Nobody" => "Ninguém",
"Shared via calendar" => "Partilhado via calendário",
"NOTE: Actions on events shared via calendar will affect the entire calendar sharing." => "NOTA: Acções ou eventos partilhados via calendário irão afectar toda a partilha de calendários",
"View an event" => "Ver um evento",
"No categories selected" => "Nenhuma categoria seleccionada",
"of" => "de",
"at" => "em",
"General" => "Geral",
"Timezone" => "Zona horária",
"Update timezone automatically" => "Actualizar automaticamente o fuso horário",
"Time format" => "Formato da hora",
"24h" => "24h",
"12h" => "12h",
"Start week on" => "Começar semana em",
"Cache" => "Memória de pré-carregamento",
"Clear cache for repeating events" => "Limpar a memória de pré carregamento para eventos recorrentes",
"URLs" => "Endereço(s) web",
"Calendar CalDAV syncing addresses" => "Endereços de sincronização de calendários CalDAV",
"more info" => "mais informação",
"Primary address (Kontact et al)" => "Endereço principal (Kontact et al.)",
"iOS/OS X" => "iOS/OS X",
"Read only iCalendar link(s)" => "Ligaç(ão/ões) só de leitura do iCalendar"
);
